#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2020-11-10
#
# Check_MK checkpoint_raid WATO plugin
#
# 2023-04-23: moved wato file to ~/local/lib/check_mk/gui/plugins/wato
#             moved rule set from networking to hardware

from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Dictionary,
    TextAscii,
    TextUnicode,
)
from cmk.gui.plugins.wato.utils import (
    CheckParameterRulespecWithItem,
    rulespec_registry,
    RulespecGroupCheckParametersHardware,
)


def _parameter_valuespec_checkpoint_raid():
    return Dictionary(
        help=_(''),
        elements=[
            ('ignore_disks',
             TextUnicode(
                 title=_('list of comma separated disk IDs to ignore'),
                 help=_('This is useful for RAID Arrays with missing disks, like on the Smart-1 5150. There the '
                        'array is configured for 12 Disk but in the default Hardware are only 6 Disks.'),
                 allow_empty=False,
             )),
        ],
    )


rulespec_registry.register(
    CheckParameterRulespecWithItem(
        check_group_name='checkpoint_raid',
        group=RulespecGroupCheckParametersHardware,
        item_spec=lambda: TextAscii(title=_('RAID ID'), ),
        match_type='dict',
        parameter_valuespec=_parameter_valuespec_checkpoint_raid,
        title=lambda: _('Check Point RAID'),
    ))
